# Ledger Nano S and Nano X Library

This is a stripped down and modified version of the official [btchip-python](https://github.com/LedgerHQ/btchip-python) library.

This stripped down version was made at commit [17f27c1996c75145b8eb5d16583bddcb6e2bf691](https://github.com/LedgerHQ/btchip-python/tree/17f27c1996c75145b8eb5d16583bddcb6e2bf691).

## Changes

- Removed support for Ledger HW.1 and other unused things

See c141b6effa78fb7a3ed52acbe17314078fe93c86 for the specific changes.
